@@ -3,7 +3,7 @@ use 5.22.0;
 no strict; no warnings; no diagnostics;
 use common::sense;
 
-our $VERSION = "0.0.4";
+our $VERSION = "0.0.5";
 
 require POSIX;
 require Term::ANSIColor;
@@ -328,9 +328,8 @@ sub kb_size($) {
 # Оставляет $n цифр до и после точки: 10.11 = 10, 0.00012 = 0.00012, 1.2345 = 1.2, если $n = 2
 sub sround($;$) {
 	my ($number, $digits) = @_;
-	require Math::BigFloat;
-	my $num = Math::BigFloat->new($number);
 	$digits //= 2;
+	my $num = sprintf("%.100f", $number);
 	$num =~ /^-?0?(\d*)\.(0*)[1-9]/;
 	return "" . round($num, $digits + length $2) if length($1) == 0;
 	my $k = $digits - length $1;
@@ -395,7 +394,7 @@ Aion::Format - Perl extension for formatting numbers, colorizing output and so o
 
 =head1 VERSION
 
-0.0.4
+0.0.5
 
 =head1 SYNOPSIS
 
